#######################
reopenGeneralForumTopic
#######################

Returns: :obj:`bool`

.. automodule:: litegram.methods.reopen_general_forum_topic
    :members:
    :member-order: bysource
    :undoc-members: True
    :exclude-members: model_config,model_fields


Usage
=====

As bot method
-------------

.. code-block::

    result: bool = await bot.reopen_general_forum_topic(...)


Method as object
----------------

Imports:

- :code:`from litegram.methods.reopen_general_forum_topic import ReopenGeneralForumTopic`
- alias: :code:`from litegram.methods import ReopenGeneralForumTopic`

With specific bot
~~~~~~~~~~~~~~~~~

.. code-block:: python

    result: bool = await bot(ReopenGeneralForumTopic(...))

As reply into Webhook in handler
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. code-block:: python

    return ReopenGeneralForumTopic(...)
